setwd("O:/Training/R Stats Course/Material for the Babraham Bioinformatics website/Data")
setwd("C:/Users/segondsa/Desktop/R Stats Course/R_Stats_Course_Data")


install.packages(c("beanplot", "plotrix", "pastecs", "reshape2"))

library(beanplot)
library(plotrix)
library(pastecs)
library(reshape2)



#### QUALITATIVE DATA #####

## power analysis ##
power.prop.test(p1 = .25, p2 = .7, power = .8, sig.level = 0.05)


## Load the data ##
cats.data<-read.table("cats.dat", sep="\t",header=T)

## Look at the data ##
head(cats.data)
View(cats.data)


## Plot the data and contingency table ##
plot(cats.data$Training, cats.data$Dance, xlab = "Training", ylab = "Dance")
plot(table(cats.data))

contingency.table <- table(cats.data)
contingency.table100<-prop.table(contingency.table,1)
contingency.table100<-round(contingency.table100*100)
contingency.table100

contingency.table100<-cbind(contingency.table100[,"Yes"],contingency.table100[,"No"])
colnames(contingency.table100) <- c("Yes", "No")
contingency.table100


barplot(t(contingency.table100), 
        legend.text = TRUE,
        ylab = "Percentages",
        las=1)

#### Pretty ###

par(lwd=2) 
barplot(t(contingency.table100), 
        col=c("chartreuse3","lemonchiffon2"),
        cex.axis=1.2, 
        cex.names=1.5,
        cex.lab=1.5,
        ylab = "Percentages",
        las=1
        )


legend("topright",   
       title="Dancing", 
       inset=.05, 
       c("Yes","No"), 
       horiz=TRUE, 
       pch=15,
       col=c("chartreuse3","lemonchiffon2"))


dev.off()





## Chi2  ##
chisq.test(contingency.table)

## Chi2 without continuity correction #
chisq.test(contingency.table, correct=F)

## Fishers test  ##
fisher.test(contingency.table)


#### QUANTITATIVE DATA #####

## Import data ##
coyote<-read.csv("coyote.csv")
View(coyote)
head(coyote)

## Power calculation # 
#power.t.test(n = , d = , sig.level = , power = , type = c("two.sample", "one.sample", "paired"))  

# mean 1 = 92 and mean 2 = 87.4
# sd = 7


delta <- 92 - 87.4


power.t.test(delta = 92 - 87.4, sd = 7, sig.level = 0.05, power = 0.8)


### Graphical exploration of the data ###

## Stripchart ##
stripchart(coyote$length~coyote$gender)
stripchart(coyote$length~coyote$gender,vertical=TRUE, method="jitter")

stripchart(coyote$length~coyote$gender,
           vertical=TRUE, 
           method="jitter", 
           las=1, 
           ylab="Length", 
           pch=16,
           col=c("darkorange","purple"), 
           cex=1.5
           )

# Add group means #
length.means <- tapply(coyote$length,coyote$gender,mean) 

segments(1:2-0.15,length.means, 1:2+0.15, length.means, col="black", lwd=3)


## Boxplot or beanplot # beanplot package ##
boxplot(coyote$length~coyote$gender,notch = TRUE)

# Prettier: 
boxplot(coyote$length~coyote$gender, col=c("orange","purple"), ylab = 'Length (cm)', las = 1)


## Beanplot ##
beanplot(coyote$length~coyote$gender,las=1,ylab="Length (cm)") 

## Combination boxplot and scatterplot ##
boxplot(coyote$length~coyote$gender, 
        lwd = 2, 
        ylab = 'Length', 
        cex.axis=1.5,
        las=1, 
        cex.lab=1.5)

stripchart(coyote$length~coyote$gender, 
           vertical = TRUE, 
           method = "jitter", 
           pch = 20, 
           col = 'red', 
           cex=2, 
           add = TRUE)

## Combination boxplot and beanplot ##
beanplot(coyote$length~coyote$gender,
         las=1, overallline = "median", 
         ylab = 'Length', 
         cex.lab=1.5, 
         col="bisque",
         what = c(0,1,1,0),
         cex.axis=1.5) 

boxplot(coyote$length~coyote$gender, 
        add=TRUE, 
        col=rgb(0.2,0.5,0.3, alpha=0.5), 
        pch = 20,  
        cex=2, 
        lwd=2, 
        yaxt='n',
        xaxt='n')



## Histogram ##
par(mfrow=c(1,2))
hist(coyote[coyote$gender=="male",]$length)
hist(coyote[coyote$gender=="female",]$length)

# Prettier:
hist(coyote[coyote$gender=="male",]$length,main="Male", xlab="Length",col="lightgreen")
hist(coyote[coyote$gender=="female",]$length,main="Female", xlab="Length",col="tomato1")



### Stats summary of test for normality (1st assumption)  ## pastecs package ###
#by(coyote$length,coyote$gender, stat.desc, basic=F, desc=F, norm=T)#
tapply(coyote$length,coyote$gender, stat.desc, basic=F, desc=F, norm=T)

### Homogeneity of variance (test 2nd assumption) 
bartlett.test(coyote$length~coyote$gender)

###### Independent t-test ###########
t.test(coyote$length~coyote$gender, var.equal=T)


## Plot a bar chart ##
dev.off()
bar.length<-barplot(length.means) 
bar.length<-barplot(length.means,xlim=c(0,1),width=0.3, ylim=c(0,100)) 


# Prettier:
bar.length<-barplot(length.means, col=c("darkslategray1","darkseagreen1"), xlim=c(0,1),width=0.3,ylim=c(50,100), ylab="Mean length",las=1, xpd=FALSE)


## Calculation of SEM for error bars # plotrix package ##
length.se<-tapply(coyote$length,coyote$gender,std.error)
length.se

# Alternative #
length.se<-tapply(coyote$length,coyote$gender,function(x) sd(x)/sqrt(length(x)))


## Barplot returns the values for the centers of the bars ##
bar.length

# Adding error bars #
arrows(x0=bar.length, y0=length.means-length.se, x1=bar.length, y1=length.means+length.se, length=0.3, angle=90,code=3)


###### Independent t-test ###########
t.test(coyote$length~coyote$gender, var.equal=T)



###### Paired t-test ###########
working.memory<-read.csv("Working.memory.csv", header=T)
head(working.memory)


### Graphical exploration of the data ###

## Boxplot ##
boxplot(working.memory[2:3])
beanplot(working.memory[2:3],las=1,ylab="Scores") 


## Stripchart ##
stripchart(working.memory[2:3])
stripchart(working.memory[2:3],vertical=TRUE, method="jitter", las=1, ylab="Scores", pch=16,col=c("darkred","darkgreen"), cex=1.5)

# Add group means #
scores.means <- colMeans(working.memory[2:3])
scores.means
segments(1:2-0.15,scores.means, 1:2+0.15, scores.means, col="black", lwd=3)


## Check assumption for normality ##
stat.desc(working.memory$placebo, basic=F, desc=F, norm=T)
stat.desc(working.memory$DA.depletion, basic=F, desc=F, norm=T)


## Running paired t-test ##
t.test(working.memory$placebo, working.memory$DA.depletion, paired=T)


## Plot the difference ##
working.memory$Difference<- working.memory$placebo-working.memory$DA.depletion
head(working.memory)
stat.desc(working.memory$Difference, basic=F, desc=F, norm=T)


## Difference as stripchart ##
stripchart(working.memory$Difference)
stripchart(working.memory$Difference,vertical=TRUE, method="jitter", las=1, ylab="Differences",pch=16, col="blue", cex=2)

diff.mean <- mean(working.memory$Difference)
loc.strip<-1
segments(loc.strip-0.15,diff.mean, loc.strip+0.15, diff.mean, col="black", lwd=3)
diff.se <- std.error(working.memory$Difference) # plotrix package #


## Confidence intervals ##
lower<-diff.mean-1.96*diff.se
upper<-diff.mean+1.96*diff.se


## Plot confidence intervals on a scatterplot ##
arrows(x0=loc.strip, y0=lower, x1=loc.strip, y1=upper, length=0.3, angle=90,code=3,lwd=3)

## Plot beanplots ##
beanplot(working.memory$Difference,las=1,ylab="Differences") 

## One-sample t-test ##
t.test(working.memory$Difference ,mu=0)


###########################################################################################
###################### ANOVA ##############################################################


# Import and plot dataset #
protein<-read.csv("protein.expression.csv",header=T)
head(protein)

protein.stack<-melt(protein) ## reshape2 package ## this will generate a warning because we do not specify the ID ##
colnames(protein.stack)<-c("line","expression")
protein.stack.clean <- protein.stack[!is.na(protein.stack$expression),]
head(protein.stack.clean)


## stripchart ##

stripchart(protein.stack.clean$expression~protein.stack.clean$line,
           vertical=TRUE,
           method="jitter",
           las=1,
           ylab="Protein Expression", 
           pch=16, 
           col=rainbow(5))

expression.means<-tapply(protein.stack.clean$expression,protein.stack.clean$line,mean)
segments(1:5-0.15,expression.means, 1:5+0.15, expression.means, col="black", lwd=3)


## boxplot, beanplot and normality test ##
boxplot(protein.stack.clean$expression~protein.stack.clean$line)
boxplot(protein.stack.clean$expression~protein.stack.clean$line,col=rainbow(5), las=1,ylab="Protein Expression") 

beanplot(protein.stack.clean$expression~protein.stack.clean$line,overallline = "median",log="",ylab="Protein Expression", las=1) ## beanplot package ##

tapply(protein.stack.clean$expression,protein.stack.clean$line,stat.desc,desc=F, basic=F, norm=T) ## pastecs package ##


## stripchart of log transformed data ##
stripchart(protein.stack.clean$log10.expression~protein.stack.clean$line,
           vertical=TRUE,
           method="jitter",
           las=1,
           ylab="Protein Expression", 
           pch=16, 
           col=rainbow(5)
)


expression.log.means<-tapply(protein.stack.clean$log10.expression,protein.stack.clean$line,mean)
segments(1:5-0.15,expression.log.means,1:5+0.15, expression.log.means, col="black", lwd=3)

beanplot(protein.stack.clean$expression~protein.stack.clean$line,overallline = "median",ylab="Protein Expression") ## beanplot package ##


# log transform y and test again #
protein.stack.clean$log10.expression<-log10(protein.stack.clean$expression)
head(protein.stack.clean)

tapply(protein.stack.clean$log10.expression,protein.stack.clean$line,stat.desc,basic=F, norm=T, desc=F)


## boxplot log transformed data ##
boxplot(protein.stack.clean$log10.expression~protein.stack.clean$line,col=rainbow(5))


# equal variance (2nd assumption) #
bartlett.test(protein.stack.clean$log10.expression~protein.stack.clean$line)

#run the anova
anova.log.protein<-aov(log10.expression~line,data=protein.stack.clean)
summary(anova.log.protein)


#par(mfrow=c(2,2))
#plot(anova.log.protein)


## Bonferroni ##
pairwise.t.test(protein.stack.clean$log10.expression,protein.stack.clean$line, p.adj = "bonf")

## Tukey ##
TukeyHSD(anova.log.protein)

## as a bar plot ##
bar.expression<-barplot(expression.means, beside=TRUE, ylab="Mean expression",ylim=c(0,3),las=1)
expression.se <- tapply(protein.stack.clean$expression, protein.stack.clean$line,std.error) 

arrows(x0=bar.expression, y0=expression.means-expression.se, x1=bar.expression, y1=expression.means+expression.se, length=0.2, angle=90,code=3)



###################################################################################
############## Correlation ########################################################

dev.off()
## Import and plot correlation data ##
exam.anxiety<-read.table("exam.anxiety.dat", sep="\t",header=T)
head(exam.anxiety)

## Plot the data ##
plot(exam.anxiety$Anxiety~exam.anxiety$Revise,col=exam.anxiety$Gender,pch=16)

## Add legend  ##
legend("topright", title="Gender",inset=.05, c("Female","Male"), horiz=TRUE, pch=16,col=1:2)

# also works: 
legend("topright", title="Gender",inset=.05, c("Female","Male"), horiz=TRUE, pch=16,col=c("black","red"))


## Fit the model ##
fit.male <- lm(Anxiety~Revise, data=exam.anxiety[exam.anxiety$Gender=="Male",])
fit.female <- lm(Anxiety~Revise, data=exam.anxiety[exam.anxiety$Gender=="Female",])

           
## Add a line of best-fit ##
abline((fit.male), col="red")
abline((fit.female), col="black")


## Check the assumptions ##
par(mfrow=c(2,2))
plot(fit.male)
plot(fit.female)


## Test the significance of the model ##
summary(fit.male)
summary(fit.female)


## Correlation ##
cor(exam.anxiety[exam.anxiety$Gender=="Male",c("Exam","Anxiety","Revise")])
cor(exam.anxiety[exam.anxiety$Gender == "Female", c("Exam","Anxiety","Revise")])

## Let's filter out the misbehaving students ##
exam.anxiety.filtered <- exam.anxiety[c(-78,-87),]


## Model without the outlier/influential case ##
fit.male2 <- lm(Anxiety~Revise, data=exam.anxiety.filtered[exam.anxiety.filtered$Gender=="Male",])
summary(fit.male2)

fit.female2 <- lm(Anxiety~Revise, data=exam.anxiety.filtered[exam.anxiety.filtered$Gender=="Female",])
summary(fit.female2)


## New correlation ##
cor(exam.anxiety.filtered[exam.anxiety.filtered$Gender=="Male",c("Exam","Anxiety","Revise")])
cor(exam.anxiety.filtered[exam.anxiety.filtered$Gender=="Female",c("Exam","Anxiety","Revise")])

## New plot ##
dev.off()
plot(exam.anxiety$Anxiety~exam.anxiety$Revise,col=exam.anxiety$Gender,pch=16)

## Add legend  ##
legend("topright", title="Gender", inset=.05, c("Female","Male"), horiz=TRUE, pch=16,col=1:2)

## Lines of best fit ##
abline((fit.male), col="red")
abline((fit.female), col="black")
abline((fit.male2), col="red",lty=3)
abline((fit.female2), col="black",lty=3)

